"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.21.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.containerization_state_enum import ContainerizationStateEnum
from delphix.api.gateway.model.oracle_rac_database_instance import OracleRACDatabaseInstance
from delphix.api.gateway.model.oracle_service import OracleService
from delphix.api.gateway.model.oracle_tde_keystore_config_type_enum import OracleTdeKeystoreConfigTypeEnum
from delphix.api.gateway.model.tag import Tag
globals()['ContainerizationStateEnum'] = ContainerizationStateEnum
globals()['OracleRACDatabaseInstance'] = OracleRACDatabaseInstance
globals()['OracleService'] = OracleService
globals()['OracleTdeKeystoreConfigTypeEnum'] = OracleTdeKeystoreConfigTypeEnum
globals()['Tag'] = Tag
from delphix.api.gateway.model.vcdb import VCDB


class TestVCDB(unittest.TestCase):
    """VCDB unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVCDB(self):
        """Test VCDB"""
        # FIXME: construct object with mandatory attributes with example values
        # model = VCDB()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.21.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.hyperscale_data_type_enum import HyperscaleDataTypeEnum
from delphix.api.gateway.model.tag import Tag
globals()['HyperscaleDataTypeEnum'] = HyperscaleDataTypeEnum
globals()['Tag'] = Tag
from delphix.api.gateway.model.hyperscale_instance_registration_parameter import HyperscaleInstanceRegistrationParameter


class TestHyperscaleInstanceRegistrationParameter(unittest.TestCase):
    """HyperscaleInstanceRegistrationParameter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHyperscaleInstanceRegistrationParameter(self):
        """Test HyperscaleInstanceRegistrationParameter"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HyperscaleInstanceRegistrationParameter()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
